	PROGRAM COMPIMP

C	BY A.K. COKER


C	******************************************************************
C	THIS PROGRAM CALCULATES EITHER POLYTROPIC OR ADIABATIC HEADS,
C	THE ASSOCIATED GAS HORSEPOWER AND GAS DISCHARGE TEMPERATURE,
C	AS LONG AS THE POLYTROPIC OR ADIABATIC EFFICIENCY IS USED
C	WITH THE COMPANION HEAD CALCULATION.  THE PROGRAM ALSO CALCULATES
C	ADIABATIC EFFICIENCY FROM POLYTROPIC EXPONENT "K" FROM THE
C	MOLAL HEAT CAPACITY (MCp).
C
C
C
C	**********************************************************************
C
C
C	Hpoly(PH)   = POLYTROPIC HEAD, ft
C	ZAV	    = AVERAGE COMPRESSIBILITY FACTOR FOR GAS FROM SUCTION TO
C		      DISCHARGE CONDITIONS. A VALUE OF 1.0 WILL GIVE
C		      CONSERVATIVE RESULTS.
C	R	    = GAS CONSTANT= 1544.
C	TS	    = SUCTION TEMPERATURE, oF
C	MW	    = MOLECULAR WEIGTH OF GAS
C	N	    = POLYTROPIC EXPONENT
C	RC	    = COMPRESSION RATIO (DISCHARGE PRESSURE/SUCTION PRESSURE)
C		      P2/P1
C	T11	    = INLET TEMPERATURE, oF
C	T12	    = DISCHARGE TEMPERATURE, oF
C	K	    = ADIABATIC EXPONENT, Cp/Cv
C	Epoly (PE)  = POLYTROPIC EFFICIENCY (TRY 0.75 FOR PRELIMINARY WORK)
C	HP	    = GAS HORSEPOWER, bhp.
C	W	    = GAS FLOW, lb/h
C	Had (AH)    = ADIABATIC HEAD, ft
C	T21	    = SUCTION TEMPERATURE, oF
C	T22	    = DISCHARGE TEMPERATURE, oF
C	Ead (AE)    = ADIABATIC EFFICIENCY
C	MCp (MCP)   = MOLAL SPECIFIC HEAT OF GAS AT CONSTANT PRESSURE,
C		      Btu/(lb mol)(oF).
C	P1	    = SUCTION PRESSURE, psia.
C	P2	    = DISCHARGE PRESSURE, psia.
C	CHOICE	    = CHOOSE WHETHER THE PROCESS IS ADIABATIC OR POLYTROPIC
C	**********************************************************************

	CHARACTER*14 CHOICE
	REAL K,MW,N
	COMMON/PROG1/W,P1,P2,T11,T12,T21,T22,K,MW,N,ZAV,AE,AECAL,RC
	COMMON/PROG2/POLYH,ADIAH,HPPOLY,HPADIA,PE,PECAL,BHPP,BHPA
	COMMON/PROG3/WORK,PROD

	OPEN (UNIT=3,FILE='COMPIMP.DAT',STATUS='OLD',ACTION='READ', ERR=18)
	OPEN (UNIT =1, FILE ='COMPRES.RES')

C
C	DETERMINE WHETHER THE COMPRESSOR CALCULATION IS POLYTROPIC
C	OR ADIABATIC.

	READ (3, 15, ERR=19) CHOICE

 15	FORMAT (A)

	IF (CHOICE .EQ. 'POLYTROPIC' .OR. CHOICE .EQ. 'polytropic') THEN

	READ (3, *, ERR=19) W, P1, P2
	READ (3, *, ERR=19) T11, K, MW
	READ (3, *, ERR=19) ZAV, PE


	GO TO 40

      ELSEIF (CHOICE .EQ. 'ADIABATIC' .OR. CHOICE .EQ. 'adiabatic') THEN

	READ (3, *, ERR=19) W, P1, P2
	READ (3, *, ERR=19) T11, K, MW
	READ (3, *, ERR=19) ZAV, AE


	GO TO 50
	ENDIF


 18	WRITE (*, 10)
 10	FORMAT (3X, 'DATA FILE DOES NOT EXIST')

	GO TO 999
 19	WRITE (*, 20)
 20	FORMAT (3X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999

 40	WRITE (1, 30)
 30	FORMAT (///,26X,'POLYTROPIC COMPRESSOR CALCULATION', /, 78(1H*))

        WRITE (*, 3000)
3000	FORMAT (///,26X,'POLYTROPIC COMPRESSOR CALCULATION', /, 78(1H*))


	CALL POLYTR

	WRITE (1, 60) CHOICE, W, P1, P2, RC
 60	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, lb/h:',T60, F12.3,/,
     *		5X,'SUCTION PRESSURE, psia:', T60, F12.3,/,
     *		5X,'DISCHARGE PRESSURE, psia:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (1, 70) T11, K, MW
 70	FORMAT (5X,'INLET TEMPERATURE, oF:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEAT CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, lb/lb-mole:',T60,F12.3)

	WRITE (1, 80) ZAV, PE
 80	FORMAT (5X,'AVERAGE COMPRESSIBILITY FACTOR, Z:',T60, F8.4,/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60,F8.2)


	WRITE (1, 90) POLYH, T12, HPPOLY
 90	FORMAT (5X,'POLYTROPIC HEAD, ft:',T60,F12.3,/,
     *		5X,'GAS DISCHARGE TEMPERATURE, oF:',T60, F12.3, /,
     *		5X,'GAS HORSEPOWER, hp:', T60, F12.3)

	WRITE (1, 100) PROD, BHPP, WORK
 100	FORMAT (5X,'MECHANICAL LOSSES, hp:', T60, F12.3,/,
     *		5X,'TOTAL BRAKE HORSEPOWER, hp:',T60, F12.3,/,
     *		5X,'WORK DONE, lb-mole/h:', T60, F12.3)

	WRITE (1, 105)
 105	FORMAT (78(1H-))

C	FORM FEED THE PRINTING PAPER TO THE TOP OF THE NEXT PAGE.

c	WRITE (1, *) CHAR(12)



	WRITE (*, 1200) CHOICE, W, P1, P2, RC
 1200	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, lb/h.:', T60, F12.3,/,
     *		5X,'SUCTION PRESSURE, psia:', T60, F12.3,/,
     *		5X,'DISCHARGE PRESSURE, psia:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)


	WRITE (*, 270) T11, K, MW
270	FORMAT (5X,'INLET TEMPERATURE, oF:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEAT CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, lb/lb-mole:',T60,F12.3)

	WRITE (*, 280) ZAV, PE
280	FORMAT (5X,'AVERAGE COMPRESSIBILITY FACTOR, Z:',T60, F8.4,/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60,F8.2)


	WRITE (*, 290) POLYH, T12, HPPOLY
 290	FORMAT (5X,'POLYTROPIC HEAD, ft:',T60,F12.3,/,
     *		5X,'GAS DISCHARGE TEMPERATURE, oF:',T60, F12.3, /,
     *		5X,'GAS HORSEPOWER, hp:', T60, F12.3)

	WRITE (*, 2000) PROD, BHPP, WORK
2000	FORMAT (5X,'MECHANICAL LOSSES, hp:', T60, F12.3,/,
     *		5X,'TOTAL BRAKE HORSEPOWER, hp:',T60, F12.3,/,
     *		5X,'WORK DONE, lb-mole/h:', T60, F12.3)










	WRITE (*, 1900)
 1900	FORMAT (1H ,78(1H-))


	GO TO 999

 50	WRITE (1, 110)
 110	FORMAT (///,26X,'ADIABATIC COMPRESSOR CALCULATION', /, 78(1H*))

	CALL ADIAB

	WRITE (1, 120) CHOICE, W, P1, P2, RC
 120	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, lb/hr.:', T60, F12.3,/,
     *		5X,'SUCTION PRESSURE, psia:', T60, F12.3,/,
     *		5X,'DISCHARGE PRESSURE, psia:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (1, 130) T11, K, MW
 130	FORMAT (5X,'INLET TEMPERATURE, oF:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEATS CAPACITIES, K:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, lb/lb-mole:',T60, F12.3)

	WRITE (1, 140) ZAV, AE
 140	FORMAT (5X,'AVERAGE COMPRESSIBILITY FACTOR, Z:',T60, F8.4,/,
     *		5X,'ADIABATIC EFFICIENCY:',T60, F12.3)

	WRITE (1, 150) ADIAH, T22, HPADIA
 150	FORMAT (5X,'ADIABATIC HEAD, ft.:',T60, F12.3,/,
     *		5X,'GAS DISCHARGE TEMPERATURE, oF:', T60, F12.3,/,
     *		5X, 'GAS HORSEPOWER, hp:', T60, F12.3)

	WRITE (1, 160) PROD
 160	FORMAT (5X,'MECHANICAL LOSSES, hp:',T60, F12.3)

	WRITE (1, 170) BHPA, WORK
 170	FORMAT (5X,'TOTAL BRAKE HORSEPOWER, hp:',T60, F12.3,/,
     *		5X,'WORK DONE, ft/lb-mole:',T60,F12.3)

	WRITE (1, 180) AECAL
 180	FORMAT (5X,'CALCULATED ADIABATIC EFFICIENCY FROM',/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60, F12.3)

	WRITE (1, 190)
 190	FORMAT (1H ,78(1H-))












 	WRITE (*, 2110)
2110	FORMAT (///,26X,'ADIABATIC COMPRESSOR CALCULATION', /, 78(1H*))

	

	WRITE (*, 2120) CHOICE, W, P1, P2, RC
2120	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, lb/hr.:', T60, F12.3,/,
     *		5X,'SUCTION PRESSURE, psia:', T60, F12.3,/,
     *		5X,'DISCHARGE PRESSURE, psia:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (*, 2130) T11, K, MW
2130	FORMAT (5X,'INLET TEMPERATURE, oF:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEATS CAPACITIES, K:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, lb/lb-mole:',T60, F12.3)

	WRITE (*, 2140) ZAV, AE
2140	FORMAT (5X,'AVERAGE COMPRESSIBILITY FACTOR, Z:',T60, F8.4,/,
     *		5X,'ADIABATIC EFFICIENCY:',T60, F12.3)

	WRITE (*, 2150) ADIAH, T22, HPADIA
2150	FORMAT (5X,'ADIABATIC HEAD, ft.:',T60, F12.3,/,
     *		5X,'GAS DISCHARGE TEMPERATURE, oF:', T60, F12.3,/,
     *		5X, 'GAS HORSEPOWER, hp:', T60, F12.3)

	WRITE (*, 2160) PROD
2160	FORMAT (5X,'MECHANICAL LOSSES, hp:',T60, F12.3)

	WRITE (*, 2170) BHPA, WORK
2170	FORMAT (5X,'TOTAL BRAKE HORSEPOWER, hp:',T60, F12.3,/,
     *		5X,'WORK DONE, ft/lb-mole:',T60,F12.3)

	WRITE (*, 2180) AECAL
2180	FORMAT (5X,'CALCULATED ADIABATIC EFFICIENCY FROM',/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60, F12.3)

	WRITE (*, 2190)
2190	FORMAT (1H ,78(1H-))




C	----------------------------------------------------




	CLOSE (3,STATUS='KEEP')
	CLOSE (1)
  999	STOP
	END


C	*****************************************************************
C	THIS PROGRAM CALCULATES THE POLYTROPIC HEAD,THE ASSOCIATED GAS
C	HORSEPOWER AND GAS DISCHARGE TEMPERATURE IN POLYTROPIC MACHINES
C	*****************************************************************

	SUBROUTINE POLYTR
	REAL K,MW,N,MLOSS
	COMMON/PROG1/W,P1,P2,T11,T12,T21,T22,K,MW,N,ZAV,AE,AECAL,RC
	COMMON/PROG2/POLYH,ADIAH,HPPOLY,HPADIA,PE,PECAL,BHPP,BHPA
	COMMON/PROG3/WORK, PROD

	R = 1545.0
	T11 = T11 + 460.


C	CALCULATE THE COMPRESSION RATIO (DISCHARGE PRESS./SUCTION PRESS.)

	RC = P2/P1
	N = (K*PE)/(K*PE-K+1.0)


C	CALCULATE THE POLYTROPIC HEAD, POLYH: ft.

	VAL1 = (ZAV*R*T11)/MW
	VAL2 = (N/(N-1.0))*(RC**((N-1.0)/N)-1.0)
	POLYH = VAL1*VAL2

C	CALCULATE THE GAS HORSEPOWER, HPPOLY: hp.

	HPPOLY = (W*POLYH)/(1.98*(10.0**6)*PE)

C	CALCULATE THE APPROXIMATE MECHANICAL LOSSES AS A PERCENTAGE OF GAS
C	POWER REQUIREMENT, PROD: hp.

	CALL MECHL (HPPOLY, MLOSS)

C	CALCULATE THE TOTAL BRAKE HORSEPOWER, BHPP: hp.

	BHPP = HPPOLY + PROD

C	CALCULATE THE GAS DISCHARGE TEMPERATURE, T12: oF.

	VAL3 = (POLYH*MW)/(ZAV*R)
	T12 = VAL3*((N-1.0)/N) + T11

C	CALCULATE THE WORK DONE  lb- mole/hr.
C	CALCULATE THE BASIS IN moles.

	B = W/MW

C	CALCULATE THE WORK DONE

	WORK = (N/(N-1.0))*(R*T11*((P2/P1)**((N-1.0)/N)-1.0))
	WORK = (WORK*B)/(1.98*(10.0**6))

	T11 = T11 - 460.0
	T12 = T12 - 460.0

	RETURN
	END
C
C	*****************************************************************
C	THIS PROGRAM CALCULATES THE ADIABATIC HEAD,THE ASSOCIATED GAS
C	HORSEPOWER AND GAS DISCHARGE TEMPERATURE
C	*****************************************************************

	SUBROUTINE ADIAB
	REAL K,MW,N,MLOSS
	COMMON/PROG1/W,P1,P2,T11,T12,T21,T22,K,MW,N,ZAV,AE,AECAL,RC
	COMMON/PROG2/POLYH,ADIAH,HPPOLY,HPADIA,PE,PECAL,BHPP,BHPA
	COMMON/PROG3/WORK, PROD

	PE = 0.75
	R = 1545.0
	T21 = T11 + 460.

C	CALCULATE THE COMPRESSION RATIO (DISCHARGE PRESS./SUCTION PRESS.)

	RC = P2/P1


C	CALCULATE THE ADIABATIC HEAD, ADIAH: ft.

	VAL4 = (ZAV*R*T21)/MW
	VAL5 = (K/(K-1.0))*(RC**((K-1.0)/K)-1.0)
	ADIAH = VAL4*VAL5

C	CALCULATE THE GAS HORSEPOWER, HPADIA: hp.

	HPADIA = (W*ADIAH)/(1.98*(10.0**6)*AE)


C	CALCULATE THE APPROXIMATE MECHANICAL LOSSES AS A PERCENTAGE OF GAS
C	POWER REQUIREMENT, PROD: hp.

	CALL MECHL (HPADIA, MLOSS)

C	CALCULATE THE TOTAL BRAKE HORSEPOWER, BHPA: hp.

	BHPA = HPADIA + PROD

C	CALCULATE THE GAS DISCHARGE TEMPERATURE, oF.

	T22 = T21*(RC**((K-1.0)/K))
	T22 = T22 - 460.0

C	CALCULATE THE ADIABATIC EFFICIENCY FROM THE POLYTROPIC EFFICIENCY

	N = (K*PE)/(K*PE-K+1.0)
	VAL6 = (RC**((K-1.0)/K))-1.0
	VAL7 = (RC**((N-1.0)/N))-1.0
	AECAL = VAL6/VAL7

C	CALCULATE THE WORK DONE, hp

C	CALCULATE THE BASIS IN lb-moles per hr.

	B = W/MW

C	CALCULATE THE WORK DONE

	WORK = (K/(K-1.0))*(R*T21)*((P2/P1)**((K-1.0)/K)-1.0)
	WORK = (WORK*B)/(1.98*(10.0**6))

	RETURN
	END

C	**************************************************************
C	THIS PROGRAM CALCULATES THE MECHANICAL LOSSES DUE TO
C	FRICTION IN BEARINGS.
C	**************************************************************

	SUBROUTINE MECHL (POLYL, MLOSS)

	COMMON/PROG3/WORK,PROD
	REAL MLOSS

	IF (POLYL .LT. 3000.0 ) THEN
	MLOSS = 0.03
	PROD = POLYL*MLOSS
	ELSEIF (POLYL .GT. 3000.0 .AND. POLYL .LT. 6000.0) THEN
	MLOSS = 0.025
	PROD = POLYL*MLOSS
	ELSEIF (POLYL .GT. 6000.0 .AND. POLYL .LT. 10000.0) THEN
	MLOSS = 0.02
	PROD = POLYL*MLOSS
	ELSEIF (POLYL .GT. 10000.0) THEN
	MLOSS = 0.015
	PROD = POLYL*MLOSS
	ENDIF

	RETURN
	END

                                                                                                
