        	PROGRAM COMPRES

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY 2015
C	U.K.

C	******************************************************************
C	THIS PROGRAM CALCULATES EITHER POLYTROPIC OR ADIABATIC HEADS,
C	THE ASSOCIATED GAS HORSEPOWER AND GAS DISCHARGE TEMPERATURE,
C	AS LONG AS THE POLYTROPIC OR ADIABATIC EFFICIENCY IS USED
C	WITH THE COMPANION HEAD CALCULATION.  THE PROGRAM ALSO CALCULATES
C	ADIABATIC EFFICIENCY FROM POLYTROPIC EXPONENT "K" FROM THE
C	MOLAL HEAT CAPACITY (MCp).
C
C
C
C	**********************************************************************
C
C
C	Hpoly(PH)        = POLYTROPIC HEAD, kN-m/kg
C	Z1               = INLET COMPRESSIBILITY FACTOR
C      Z2                = OUTLET COMPRESSIBILITY FACTOR
C      ZAV	         = AVERAGE COMPRESSIBILITY FACTOR FOR GAS FROM INLET TO
C		           OUTLET CONDITIONS. A VALUE OF 1.0 WILL GIVE
C		           CONSERVATIVE RESULTS.
C	R	         = GAS CONSTANT= 8.314
C	MW	         = MOLECULAR WEIGTH OF GAS
C	N	         = POLYTROPIC EXPONENT
C	RC	         = COMPRESSION RATIO (DISCHARGE PRESSURE/SUCTION PRESSURE)
C		            P2/P1
C	T11	         = INLET TEMPERATURE, oC
C	T12	         = OUTLET TEMPERATURE, oC
C	K	         = ADIABATIC EXPONENT, Cp/Cv
C	Epoly (PE)       = POLYTROPIC EFFICIENCY (TRY 0.75 FOR PRELIMINARY WORK)
C	HP	         = GAS HORSEPOWER, kW
C	W	         = GAS FLOW, kgb/h
C	Had (AH)         = ADIABATIC HEAD, kN- m/kg
C	T21	         =  INLET TEMPERATURE, oC
C	T22	         = OUTLET TEMPERATURE, oC
C	Ead (AE)         = ADIABATIC EFFICIENCY
C	MCp (MCP)        = MOLAL SPECIFIC HEAT OF GAS AT CONSTANT PRESSURE,
C		                J/kg mol)(oC).
C	P1	         = INLET PRESSURE,bara.
C	P2	         = OUTLET PRESSURE, bara.
C	CHOICE	         = CHOOSE WHETHER THE PROCESS IS ADIABATIC OR POLYTROPIC
C	**********************************************************************

	CHARACTER*14 CHOICE
	REAL K, MW, N
	COMMON/PROG1/W, P1, P2,T11,T12,T21,T22,K,MW, N,Z1, Z2, ZAV,AE,AECAL,RC
	COMMON/PROG2/ POLYH, ADIAH, HPPOLY, HPADIA, PE, PECAL, BHPP, BHPA
	COMMON/PROG3/WORK, PROD
        COMMON/PROG4/RHO1, VOL1, RHO2, VOL2
        COMMON/PROG5/ WDPOLY, ACTPWD, POWERP, TOTALP



	OPEN (UNIT=3,FILE='DCOMPI.DAT',STATUS='OLD',ERR=18)
	OPEN (UNIT =1, FILE ='RCOMPI.RES')

C
C	DETERMINE WHETHER THE COMPRESSOR CALCULATION IS POLYTROPIC
C	OR ADIABATIC.

	READ (3, 15, ERR=19) CHOICE

 15	FORMAT (A)

	IF (CHOICE .EQ. 'POLYTROPIC' .OR. CHOICE .EQ. 'polytropic') THEN

	READ (3, *, ERR=19) W, P1, P2
	READ (3, *, ERR=19) T11, K, MW
	READ (3, *, ERR=19) Z1, Z2, PE


	GO TO 40

      ELSEIF (CHOICE .EQ. 'ADIABATIC' .OR. CHOICE .EQ. 'adiabatic') THEN

	READ (3, *, ERR=19) W, P1, P2
	READ (3, *, ERR=19) T11, K, MW
	READ (3, *, ERR=19) Z1, Z2,  AE


	GO TO 50
	ENDIF


 18	WRITE (*, 10)
 10	FORMAT (3X, 'DATA FILE DOES NOT EXIST')

	GO TO 999
 19	WRITE (*, 20)
 20	FORMAT (3X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999

 40	WRITE (1, 30)
 30	FORMAT (///,26X,'POLYTROPIC COMPRESSION CALCULATION', /, 78(1H*))
     
     
     	   WRITE (*, 1000)
 1000 FORMAT (///,26X,'POLYTROPIC COMPRESSION CALCULATION', /, 78(1H*))
     
     

	CALL POLYTR

	WRITE (1, 60) CHOICE, W, P1, P2, RC
 60	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, kg/hr.:',T60, F12.3,/,
     *		5X,'INLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'OUTLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (1, 70) T11, N, K, MW
 70	FORMAT (5X,'INLET TEMPERATURE, oC:',T60, F12.3,/,
     *         5X,'POLYTROPIC EXPONENT, n:', T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEAT CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, kg/kg-mole:',T60,F12.3)

         WRITE (1, 75) RHO1, VOL1, RHO2, VOL2
 75    FORMAT (5X, 'INLET DENSITY, kg/m^3:', T60, F12.4,/,
     *    5X,'INLET VOLUMETRIC FLOW RATE, m^3/min:', T60, F12.3,/,
     *     5X,'OUTLET DENSITY, kg/m^3:', T60, F12.4,/,
     *      5X,'OUTLET VOLUMETRIC FLOWRATE, m^3/min.:', T60, F12.3) 

	WRITE (1, 80) Z1, Z2, ZAV, PE, AE
 80	FORMAT (5X,'INLET COMPRESSIBILITY FACTOR, Z1:',T60, F8.4,/,
     *           5X, 'OUTLET COMPRESSIBILITY FACTOR, Z2:',T60,F8.4,/,
     *           5X,'AVERAGE COMPRESSIBILITY FACTOR, ZAV:', T60,F8.4/,
     *		  5X,'POLYTROPIC EFFICIENCY (%):',T60,F8.4,/,
     *           5X,'CALCULATED ADIABATIC EFFICIENCY (%):',T60,F8.4)


	WRITE (1, 90) POLYH, ADIAH, T12,  WDPOLY, ACTPWD
 90	FORMAT (5X,'POLYTROPIC HEAD, kN-m/kg:',T60,F12.3,/,
     *         5X,'ADIABATIC HEAD, kN-m/kg:', T60, F12.3,/,
     *		5X,'OUTLET TEMPERATURE, oC:',T60, F12.3, /,
     *         5X,'WORK DONE, kJ/kg:', T60, F12.3,/,
     *		5X,'ACTUAL WORKDONE, kJ/kg:', T60, F12.3)

	WRITE (1, 100) POWERP, PROD, TOTALP
100	FORMAT (5X,'POWER DEMAND BY THE COMPRESSOR, kW:',T60, F12.3,/,
     *          5X,'MECHANICAL LOSSES, kW:', T60, F12.3,/,
     *		5X,'TOTAL POWER, kW:',T60, F12.3)
 
	WRITE (1, 105)
 105	FORMAT (78(1H-))

C-----------------------------------------------------------------------------------------------------

	WRITE (*, 600) CHOICE, W, P1, P2, RC
600	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, kg/hr.:',T60, F12.3,/,
     *		5X,'INLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'OUTLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (*, 700) T11, N, K, MW
700	FORMAT (5X,'INLET TEMPERATURE, oC:',T60, F12.3,/,
     *         5X,'POLYTROPIC EXPONENT, n:', T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEAT CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, kg/kg-mole:',T60,F12.3)


          WRITE (* , 750) RHO1, VOL1, RHO2, VOL2
750    FORMAT (5X, 'INLET DENSITY, kg/m^3:', T60, F12.4,/,
     *    5X,'INLET VOLUMETRIC FLOW RATE, m^3/min:', T60, F12.4,/,
     *     5X,'OUTLET DENSITY, kg/m^3:', T60, F12.4/,
     *      5X,'OUTLET VOLUMETRIC FLOWRATE, m^3/min.:', T60, F12.4) 


	WRITE (*, 800) Z1, Z2, ZAV, PE, AE
800	FORMAT (5X,'INLET COMPRESSIBILITY FACTOR, Z1:',T60, F8.4,/,
     *           5X, 'OUTLET COMPRESSIBILITY FACTOR, Z2:',T60,F8.4,/,
     *            5X,'AVERAGE COMPRESSIBILITY FACTOR, ZAV:', T60, F8.4,/,
     *		  5X,'POLYTROPIC EFFICIENCY (%):',T60,F8.4,/,
     *           5X,'CALCULATED ADIABATIC EFFICIENCY (%):',T60,F8.4)


	WRITE (*, 900) POLYH, ADIAH, T12, WDPOLY, ACTPWD
900	FORMAT (5X,'POLYTROPIC HEAD, kN-m/kg:',T60,F12.3,/,
     *         5X,'ADIABATIC HEAD, kN-m/kg:', T60, F12.3,/,
     *		5X,'OUTLET TEMPERATURE, oC:',T60, F12.3, /,
     *         5X,'WORK DONE, kJ/kg:', T60, F12.3,/,
     *		5X,'ACTUAL WORK DONE, kJ/kg:', T60, F12.3)

	 WRITE (*, 1010) POWERP,  PROD, TOTALP
1010  FORMAT(5X, 'POWER DEMAND BY THE COMPRESSOR, kW:', T60, F12.3,/,
     *         5X,'MECHANICAL LOSSES, kW:', T60, F12.3,/,
     *		5X,'TOTAL POWER, kW:',T60, F12.3)
 
	WRITE (*, 1050)
1050	FORMAT (78(1H-))



C----------------------------------------------------------------------------------------------------
	GO TO 999

 50	WRITE (1, 110)
 110	FORMAT (///,26X,'ADIABATIC COMPRESSION CALCULATION', /, 78(1H*))

	WRITE (*, 1800)
 1800	FORMAT (///,26X,'ADIABATIC COMPRESSION CALCULATION', /, 78(1H*))


	CALL ADIAB

	WRITE (1, 120) CHOICE, W, P1, P2, RC
 120	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, kg/hr.:', T60, F12.3,/,
     *		5X,'INLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'OUTLET PRESSURE, bara:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO:', T60, F12.3)

	WRITE (1, 130) T11, K, MW
 130	FORMAT (5X,'INLET TEMPERATURE, oC:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEATS CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, kg/kg-mole:',T60, F12.3)

        WRITE (1, 132) RHO1, VOL1, RHO2, VOL2
132    FORMAT (5X, 'INLET DENSITY, kg/m^3:', T60, F12.4,/,
     *    5X,'INLET VOLUMETRIC FLOW RATE, m^3/min:', T60, F12.3,/,
     *     5X,'OUTLET DENSITY, kg/m^3:', T60, F12.4,/,
     *      5X,'OUTLET VOLUMETRIC FLOWRATE, m^3/min.:', T60, F12.3) 


	     WRITE (1, 140) Z1, Z2, ZAV, AE
140   FORMAT(5X,'INLET COMPRESSIBILITY FACTOR, Z1:',T60, F8.4,/,
     *           5X, 'OUTLET COMPRESSIBILITY FACTOR, Z2:',T60, F8.4,/,
     *           5X,'AVERAGE COMPRESSIBILITY FACTOR, ZAV:', T60,F8.4,/,
     *		5X,'ADIABATIC EFFICIENCY, %:',T60,F8.4)

	 WRITE (1, 150) ADIAH, T22, WORK, HPADIA
 150	FORMAT (5X,'ADIABATIC HEAD, kN- m/kg.:',T60, F12.3,/,
     *		5X,'OUTLET TEMPERATURE, oC:', T60, F12.3,/,
     *         5X,'WORK DONE, kJ/kg:', T60, F12.3,/,   
     *		5X, 'ADIABATIC POWER, kW:', T60, F12.3)

	WRITE (1, 160) PROD
 160	FORMAT (5X,'MECHANICAL LOSSES, kW:',T60, F12.3)

	WRITE (1, 170) BHPA
 170	FORMAT (5X,'TOTAL POWER, kW:',T60, F12.3)

	WRITE (1, 180) AECAL
 180	FORMAT (5X,'CALCULATED ADIABATIC EFFICIENCY FROM',/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60, F12.3)

	WRITE (1, 190)
 190	FORMAT (1H ,78(1H-))

C---------------------------------------------------------------------------------------------------


	WRITE (*, 125) CHOICE, W, P1, P2, RC
125	FORMAT (5X,'TYPE OF SERVICE:', T60, A,/,
     *		5X,'GAS FLOWRATE, kg/hr.:', T60, F12.3,/,
     *		5X,'SUCTION PRESSURE, bara:', T60, F12.3,/,
     *		5X,'DISCHARGE PRESSURE, bara:', T60, F12.3,/,
     *		5X,'COMPRESSION RATIO Rc:', T60, F12.3)

	WRITE (*, 135) T11, K, MW
135	FORMAT (5X,'INLET TEMPERATURE, oC:',T60, F12.3,/,
     *		5X,'RATIO OF SPECIFIC HEATS CAPACITIES, k:',T60,F12.3,/,
     *		5X,'MOLECULAR WEIGHT OF GAS, kg/kg-mole:',T60, F12.3)


           WRITE (*, 142) RHO1, VOL1, RHO2, VOL2
142    FORMAT (5X, 'INLET DENSITY, kg/m^3:', T60, F12.4,/,
     *    5X,'INLET VOLUMETRIC FLOW RATE, m^3/min:', T60, F12.3,/,
     *     5X,'OUTLET DENSITY, kg/m^3:', T60, F12.4,/,
     *      5X,'OUTLET VOLUMETRIC FLOWRATE, m^3/min.:', T60, F12.3) 



	     WRITE (*, 145) Z1, Z2, ZAV, AE
145   FORMAT(5X,'INLET COMPRESSIBILITY FACTOR, Z1:',T60, F8.4,/,
     *           5X, 'OUTLET COMPRESSIBILITY FACTOR, Z2:',T60, F8.4,/,
     *           5X,'AVERAGE COMPRESSIBILITY FACTOR, ZAV:', T60,F8.4,/,
     *		5X,'ADIABATIC EFFICIENCY, %:',T60,F8.4)

	 WRITE (*, 155) ADIAH, T22, WORK, HPADIA
155	FORMAT (5X,'ADIABATIC HEAD, kN-m/kg.:',T60, F12.3,/,
     *		5X,'OUTLET TEMPERATURE, oC:', T60, F12.3,/,
     *          5X,'WORK DONE, kJ/kg:', T60, F12.3,/,
     *		5X, 'ADIABATIC HEAD, kN-m/kg:', T60, F12.3)

	WRITE (*, 165) PROD
165	FORMAT (5X,'MECHANICAL LOSSES, kW:',T60, F12.3)

	WRITE (*, 175) BHPA
175	FORMAT (5X,'TOTAL POWER, kW:',T60, F12.3)

	WRITE (*, 185) AECAL
185	FORMAT (5X,'CALCULATED ADIABATIC EFFICIENCY FROM',/,
     *		5X,'POLYTROPIC EFFICIENCY:',T60, F12.3)

	WRITE (*, 195)
195	FORMAT (1H ,78(1H-))

C---------------------------------------------------------------------------------------------------

	GO TO 999

 
	CLOSE (3,STATUS='KEEP')
	CLOSE (1)
  999	STOP
	END


C	*****************************************************************
C	THIS PROGRAM CALCULATES THE POLYTROPIC HEAD,THE ASSOCIATED GAS
C	HORSEPOWER AND GAS DISCHARGE TEMPERATURE IN POLYTROPIC MACHINES
C	*****************************************************************

	SUBROUTINE POLYTR
	
	REAL K, MW, N, MLOSS
	
	COMMON/PROG1/W,P1,P2,T11,T12,T21,T22,K,MW,N,Z1, Z2, ZAV,AE,AECAL,RC
	COMMON/PROG2/ POLYH,ADIAH,HPPOLY,HPADIA,PE,PECAL,BHPP,BHPA
	COMMON/PROG3/WORK, PROD
        COMMON/PROG4/RHO1, VOL1, RHO2, VOL2
        COMMON/PROG5/ WDPOLY, ACTPWD, POWERP, TOTALP
        

C          R, R1 = Universal gas  constants, R= 8.314 kJ/kmole.K 
C           R1 = 8.314 kPa (abs) m^3/kmole. K   

	 R = 8.314

	 R1 = 8.314

	T11 = T11 + 273.15
        

C	CALCULATE THE COMPRESSION RATIO (DISCHARGE PRESS./SUCTION PRESS.)

	RC = P2/P1

C        CALCULATE THE INLET DENSITY OF THE GAS, kg/m^3

         RHO1 = (P1*100.0 * MW )/ (Z1 * R * T11)


C       CALCULATE THE INLET VOLUMETRIC FLOW RATE, m^3/min.

         VOL1 = (W/(60.0 * RHO1))


C	 CALCULATE THE POLYTROPIC EXPONENT N:

	N = (K*PE)/(K*PE-K+1.0)
	
	
C	 CALCULATE THE ADIABATIC EFFICIENCY (%) AE

	AE = (RC**((K-1.0)/K) - 1.0)/(RC**((N-1)/N) - 1.0)

C	CALCULATE THE POLYTROPIC HEAD, POLYH: kN-m/kg

	ZAV = (Z1 + Z2)/2.0

	VAL1 = (ZAV*R*T11)/MW
	VAL2 = (N/(N-1.0))*(RC**((N-1.0)/N)-1.0)
	POLYH = VAL1*VAL2

C        CALCULATE THE ADIABATIC HEAD, ADIAH, kN-m/kg.

	VAL4 = (ZAV*R*T11)/MW
	VAL5 = (K/(K-1.0))*(RC**((K-1.0)/K)-1.0)
	ADIAH = VAL4*VAL5

C	 CALCULATE THE WORK DONE, kJ/kg

         VAL6 =   (N/(N-1))* (Z1*R*T11/MW)             

        VAL7 = (RC**((N-1.0)/N)-1.0)

C       WRITE (*, 555) VAL6, VAL7
C 555  FORMAT (3X, 'VAL6 = ', F12.3, 3X, 'VAL7=', F12.3)
 
C         PAUSE
C        PAUSE

	 WDPOLY = VAL6 * VAL7 

C	 CALCULATE THE ACTUAL WORK DONE, kJ/kg.

	ACTPWD = WDPOLY/PE	


C	CALCULATE THE BRAKE POWER REQUIRED BY THE COMPRESSOR, kW..

	POWERP  = (W*ACTPWD)/3600.0
	
	
C	  WRITE (*, 111) WDPOLY, ACTPWD, POWERP
C111   FORMAT(3X,'WDPOLY=', F12.3, 3X, 'ACTPWD=',F12.3,3X,
C     *    'POWERP=', F12.4)

C       PAUSE
C       PAUSE
	
C	 CALCULATE THE TOTAL POWER REQUIRED BY THE COMPRESSOR	

C	 FIRST CALCULATE THE MECHANICAL LOSSES DUE TO FRICTION IN THE BEARINGS.


	POWER = POWERP * 1.3410
	
C	WRITE (*, 222) POWER
C 222  FORMAT(3X,'POWERP=', F12.3)
 
C         pause

C	CALCULATE THE APPROXIMATE MECHANICAL LOSSES AS A PERCENTAGE OF GAS
C	POWER REQUIREMENT, PROD: hp.

	CALL MECHL (POWER, MLOSS)

C	CALCULATE THE TOTAL BRAKE HORSEPOWER, BHPP: hp.

	BHPP = POWER + PROD

C         WRITE (*, 333) BHPP
C 333    FORMAT (3X,'BHPP = ', F12.3)
 
C          PAUSE
C          PAUSE

C	CALCULATE THE MECHANICAL LOSSES IN kW

	PROD = PROD/1.3410
	
C	CALCULATE THE TOTAL POWER, TOTALP: kW

C	TOTALP = BHPP / 1.3410	

        TOTALP = POWERP  + PROD

C         WRITE (*, 444) TOTALP
C  444  FORMAT (3X, 'TOTALP = ', F12.3)

C        PAUSE
C       PAUSE       

C	CALCULATE THE GAS DISCHARGE TEMPERATURE, T12: oC.

C	VAL3 = (POLYH*MW)/(ZAV*R)
C	T12 = VAL3*((N-1.0)/N) + T11

        VALUE = RC**((N-1.0)/N)


        T12 = T11 * VALUE

C         WRITE (*, 666) N, RC, VALUE, T11, T12
C666   FORMAT (3X, 'N =', F12.4, 3X, 'RC=', F12.4, 3X, 
C    *   'VALUE=', F12.3, 3X, 'T11=', F12.3, 3X, 'T12=', F12.3)
     
C           PAUSE
C        PAUSE

 
C        CALCULATE THE OUTLET DENSITY, RHO2

                 
         RHO2 = (P2*100 * MW)/(Z2 * R1 * T12)
         
         
C       CALCULATE THE OUTLET VOLUMETRIC FLOW RATE, VOL2, m^3/min.

         VOL2 = W / (RHO2 * 60)


C	CALCULATE THE WORK DONE  kJ/kg


C	CALCULATE THE WORK DONE

C	 CALC = (RC*T12*((P2/P1)**((N-1.0)/N)-1.0))

C        WORK =  (R1/MW) *(N/(N-1.0))*CALC
      
C	CALCULATE THE POLYTROPIC EFFICIENCY IN %, PE

	PE = PE * 100.0
	
C	CALCULAE THE ADIABATIC EFFICIENCY IN %, AE

	AE  = AE * 100.0	

	T11 = T11 - 273.15
	T12 = T12 - 273.15

	RETURN
	END
C
C	*****************************************************************
C	THIS PROGRAM CALCULATES THE ADIABATIC HEAD,THE ASSOCIATED GAS
C	HORSEPOWER AND GAS DISCHARGE TEMPERATURE
C	*****************************************************************

	SUBROUTINE ADIAB
	
	REAL K,MW,N,MLOSS
	COMMON/PROG1/W,P1,P2,T11,T12,T21,T22,K,MW,N,Z1, Z2, ZAV,AE,AECAL,RC
	COMMON/PROG2/ POLYH,ADIAH,HPPOLY,HPADIA,PE,PECAL,BHPP,BHPA
	COMMON/PROG3/WORK, PROD

	PE = 0.75
	R =8.314
	T21 = T11 + 273.15

C	CALCULATE THE COMPRESSION RATIO (DISCHARGE PRESS./SUCTION PRESS.)

	RC = P2/P1

C       CALCULATE THE AVERAGE COMPRESSIBILITY FACTOR, ZAV       

        ZAV = (Z1 + Z2) / 2.0

C	CALCULATE THE ADIABATIC HEAD, ADIAH: kN-m/kg.

	VAL4 = (ZAV*R*T21)/MW
	VAL5 = (K/(K-1.0))*(RC**((K-1.0)/K)-1.0)
	ADIAH = VAL4*VAL5

C	CALCULATE THE GAS HORSEPOWER, HPADIA: kW.

	HPADIA = (W*ADIAH)/( 3.6 *(10.0**6)*AE)


C	CALCULATE THE APPROXIMATE MECHANICAL LOSSES AS A PERCENTAGE OF GAS
C	POWER REQUIREMENT, PROD: kW.

	CALL MECHL (HPADIA, MLOSS)

C	CALCULATE THE TOTAL BRAKE HORSEPOWER, BHPA: kW.

	BHPA = HPADIA + PROD

C	CALCULATE THE GAS DISCHARGE TEMPERATURE, oC.

	T22 = T21*(RC**((K-1.0)/K))
	
	
	T22 = T22 - 460.0

C	CALCULATE THE ADIABATIC EFFICIENCY FROM THE POLYTROPIC EFFICIENCY

	N = (K*PE)/(K*PE-K+1.0)
	VAL6 = (RC**((K-1.0)/K))-1.0
	VAL7 = (RC**((N-1.0)/N))-1.0
	AECAL = VAL6/VAL7


	RETURN
	END

C	**************************************************************
C	THIS PROGRAM CALCULATES THE MECHANICAL LOSSES DUE TO
C	FRICTION IN BEARINGS.
C	**************************************************************

	SUBROUTINE MECHL (POLYL, MLOSS)

	COMMON/PROG3/WORK,PROD
	REAL MLOSS

	IF (POLYL .LT. 3000.0 ) THEN
	
	MLOSS = 0.03
	
	PROD = POLYL*MLOSS
	
	ELSEIF (POLYL .GT. 3000.0 .AND. POLYL .LT. 6000.0) THEN
	
	MLOSS = 0.025
	
	PROD = POLYL*MLOSS
	
	ELSEIF (POLYL .GT. 6000.0 .AND. POLYL .LT. 10000.0) THEN
	
	MLOSS = 0.02
	
	PROD = POLYL*MLOSS
	
	ELSEIF (POLYL .GT. 10000.0) THEN
	
	MLOSS = 0.015
	
	PROD = POLYL*MLOSS
	
	ENDIF

	RETURN

	END

                                                                                                
